package de.bsvrz.iav.glprog.glprog;

import java.util.logging.ConsoleHandler;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.bitctrl.resource.Configuration;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.CommunicationError;
import de.bsvrz.dav.daf.main.ConnectionException;
import de.bsvrz.dav.daf.main.InconsistentLoginException;
import de.bsvrz.dav.daf.main.MissingParameterException;
import de.bsvrz.iav.gllib.gllib.modell.GanglinienobjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.ObjektFactory;

@SuppressWarnings("nls")
public final class DavUtil {

	private static boolean isConnected = false;

	public synchronized static void ensureConnected() {
		if (!isConnected) {
			connect();
			isConnected = true;
		}
	}

	private static void connect() {
		final ObjektFactory factory;
		final ClientDavConnection verbindung;
		final Configuration konfig;
		final Level level;

		final Logger log = Logger.getLogger(DavUtil.class.getName());

		konfig = Configuration.getConfiguration();
		level = Level.parse(konfig.getString("debug.level"));
		log.setLevel(level);
		final Handler handler = new ConsoleHandler();
		handler.setLevel(level);
		log.addHandler(handler);

		// Verbindung zum Datenverteiler aufbauen
		try {
			log.info("Stelle Verbindung zum Datenverteiler her ...");
			verbindung = new ClientDavConnection();
			verbindung.getClientDavParameters().setDavCommunicationAddress(
					konfig.getString("dav.host"));
			verbindung.getClientDavParameters().setDavCommunicationSubAddress(
					konfig.getInt("dav.port"));
			verbindung.connect();
			verbindung.login(konfig.getString("dav.benutzer"),
					konfig.getString("dav.kennwort"));
		} catch (final MissingParameterException ex) {
			// TODO Auto-generated catch block
			ex.printStackTrace();
			throw new IllegalStateException(ex);
		} catch (final CommunicationError ex) {
			// TODO Auto-generated catch block
			ex.printStackTrace();
			throw new IllegalStateException(ex);
		} catch (final ConnectionException ex) {
			// TODO Auto-generated catch block
			ex.printStackTrace();
			throw new IllegalStateException(ex);
		} catch (final InconsistentLoginException ex) {
			// TODO Auto-generated catch block
			ex.printStackTrace();
			throw new IllegalStateException(ex);
		}

		// Modell initialisieren
		factory = ObjektFactory.getInstanz();
		factory.setVerbindung(verbindung);
		factory.registerStandardFactories();
		factory.registerFactory(new GanglinienobjektFactory());
	}

}
