/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.1 Ganglinienprognose
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.glprog.glprog;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * Versorgt die Applikation mit lokalisierten Benutzernachrichten.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public enum GlProgMsg implements LogNachricht {

	/** Nicht für Log-Ausgaben vorgesehen. */
	Applikationsname,

	/** Nicht für Log-Ausgaben vorgesehen. */
	ApplikationsnameKurz,

	/** Parameter: 1) der falsche Ganglinientyp. */
	IllegalStateExceptionFalscherGanglinienTyp,

	/** Parameter: 1) das betroffene Prognoseintervall. */
	IllegalStateExceptionPrognoseIntervallEnthaeltKeineTagesganglinien,

	/** Parameter: 1) Anfrage, 2) Antwort, 3) Meldungstext. */
	ErrorBeimAnmeldenAntwort(Debug.ERROR),

	/** Parameter: 1) Anfrage, 2) Antwort, 3) Meldungstext. */
	ErrorBeimAntwortSenden(Debug.ERROR),

	/** Ohne Parameter. */
	ErrorArchivNichtVerfuegbar(Debug.ERROR),

	/** Parameter: 1) Thread, 2) Stack Trace. */
	ErrorUnbekannterFehler(Debug.ERROR),

	/** Parameter: 1) Fehlermeldung. */
	ErrorBeiArchivanfrage(Debug.ERROR),

	/** Ohne Parameter. */
	ErrorKalenderNichtVerfuegbar(Debug.ERROR),

	/** Parameter: 1) Fehlermeldung. */
	ErrorBeiKalenderanfrageSenden(Debug.ERROR),

	/** Parameter: 1) Anfrage, 2) Meldungstext. */
	WarningAnfrageThreadInterrupted(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt, 2) Ereignistyp. */
	WarningMehrAlsEineReferenzganglinie(Debug.WARNING),

	/** Parameter: 1) Anfrage. */
	WarningPrognoseIntervallUngueltig(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt, 2) Ereignistyp. */
	WarningKeineGanglinieFuerEreignistyp(Debug.WARNING),

	/** Prameter: 1) Ganglinienanfrage. */
	WarningKeineEreignisse(Debug.WARNING),

	/** Prameter: 1) Ganglinienanfrage, 2) Prognoseganglinie. */
	FinerPrognoseganglinie(Debug.FINER),

	/** Prameter: 1) Ganglinienanfrage, 2) Prognoseintervalle. */
	FinerPrognoseintervalle(Debug.FINER),

	/** Prameter: 1) Ganglinienanfrage, 2) Prognoseintervalle. */
	FinerPrognoseintervalleNachPriorisierteAuswahl(Debug.FINER),

	/** Prameter: 1) Ganglinienanfrage, 2) Prognoseintervalle. */
	FinerPrognoseintervalleNachEntfernenEreignisse(Debug.FINER),

	/** Prameter: 1) Ganglinienanfrage, 2) Prognoseintervalle. */
	FinerPrognoseintervalleNachMittelUndLangFristigerPrognose(Debug.FINER),

	/** Prameter: 1) Ganglinienanfrage, 2) Ergebnis des Pattern-Matchings. */
	FinerErgebnisPatternMatching(Debug.FINER),

	/** Parameter: 1) Messquerschnitt, 2) Ereignistyp. */
	WarningGanglinienInkonistent(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt. */
	WarningKeineGanglinien(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt. */
	WarningKalenderAntwortetNicht(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt, 2) Prognosezeitraum. */
	WarningKalenderKeineEreignisse(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt. 2) PID des Prognoseparameters. */
	WarningPrognoseparameterNichtGesetzt(Debug.WARNING),

	/** Parameter: 1) Anfrage. */
	WarningEmpfaengerAbgemeldet(Debug.WARNING),

	/** Parameter: 1) Messquerschnitt, 2) Prognoseparameter. */
	FinerPrognoseParameter(Debug.FINER),

	/** Parameter: 1) Messquerschnitt, 2) historische Ganglinien. */
	FinestHistotorischeGanglinien(Debug.FINEST),

	/** Ohne Parameter. */
	InfoGlProgBereit(Debug.INFO),

	/** Parameter: 1) Dauer in Sekunden, 2) Anfrage. */
	InfoDauerAnfrageInSekunden(Debug.INFO),

	/** Parameter: 1) Dauer in Millisekunden, 2) Anfrage. */
	InfoDauerAnfrageInMillisekunden(Debug.INFO),

	/** Parameter: 1) Dauer in Sekunden, 2) Ganglinienanfrage. */
	FineDauerGanglinienanfrageInSekunden(Debug.FINE),

	/** Parameter: 1) Dauer in Millisekunden, 2) Ganglinienanfrage. */
	FineDauerGanglinienanfrageInMillisekunden(Debug.FINE),

	/** Parameter: 1) Prognoseanfrage. */
	FineGangliniePrognostiziert(Debug.FINE),

	/** Parameter: 1) Maximale Anzahl gleichzeitiger Anfragen. */
	ConfigVerwaltungBereit(Debug.CONFIG),

	/** Parameter: 1) Prognoseanfrage. */
	InfoStarteAnfrage(Debug.INFO),

	/** Parameter: 1) Ganglinieanfrage. */
	FineStartBearbeitungGanglinie(Debug.FINE),

	/** Parameter: 1) Ganglinieanfrage. */
	FineWarteAufKalender(Debug.FINE),

	/** Parameter: 1) Ganglinieanfrage. */
	FineEingangsdatenKomplett(Debug.FINE),

	/** Parameter: 1) Ganglinieanfrage. */
	FineZyklischPruefen(Debug.FINE),

	/** Parameter: 1) Anfrage, 2) Antwort. */
	InfoAnfrageFertig(Debug.INFO),

	/** Parameter: 1) Ganglinieanfrage. */
	FinerKalenderAntwort(Debug.FINER),

	/** Parameter: 1) Ganglinieanfrage. */
	FineZyklischAktualisieren(Debug.FINE),

	/** Parameter: 1) Ganglinieanfrage. */
	FineZyklischSchwelleDrunter(Debug.FINE),

	/** Parameter: 1) Prognoseanfrage. */
	InfoZyklischGesendet(Debug.INFO),

	/** Parameter: 1) Ganglinieanfrage, 2) Ganglinie. */
	FinerArchivganglinie(Debug.FINER),

	/** Parameter: 1) Ganglinienanfrage, 2) Abstand neue/alte Ganglinie. */
	FinerZyklischAbstand(Debug.FINER),

	/** Parameter: 1) Ganglinieanfrage. */
	FinerStarteKalenderAnfrage(Debug.FINER),

	/** Parameter: 1) Ganglinieanfrage, 2) das aktuelle Prognoseintervall. */
	FinerPatternMatchingFuerPrognoseIntervall(Debug.FINER);

	/** Das Resource-Bundle. */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
			.getBundle(GlProgMsg.class.getCanonicalName());

	/** Die Eigenschaft {@code level}. */
	private final Level level;

	private GlProgMsg() {
		this(null);
	}

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	private GlProgMsg(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		if (level.equals(Debug.WARNING)) {
			return MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			return MessageGrade.ERROR;
		}
		return null;

	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
